﻿Start-Transcript -Path c:\tmp\logs\InitialSSL.txt -Append

# Define the path to the config file
$configFilePath = "C:\Scripts\VB365SSL\ssl.config"

# Read the content of the config file
$configContent = Get-Content $configFilePath

# Loop through each line in the config file and create variables
foreach ($line in $configContent) {
    # Skip empty lines or lines that don't have an '='
    if ($line -match "=") {
        # Split the line into key and value
        $key, $value = $line -split "=", 2
        # Trim any whitespace and create a variable dynamically
        Set-Variable -Name $key.Trim() -Value $value.Trim()
    }
}


function Load-Module ($m) {

    # If module is imported say that and do nothing
    if (Get-Module | Where-Object {$_.Name -eq $m}) {
        write-host "Module $m is already imported."
    }

    else {
        # If module is not imported, but available on disk then import
        if (Get-Module -ListAvailable | Where-Object {$_.Name -eq $m}) {
            Import-Module $m
        }

        else {
            # If module is not imported, not available on disk, but is in online gallery then install and import
            if (Find-Module -Name $m | Where-Object {$_.Name -eq $m}) {
                Install-Module -Name $m -Force -Scope AllUsers
                Import-Module $m
            }

            else {
                # If module is not imported, not available and not in online gallery then abort
                write-host "Module $m not imported, not available and not in online gallery, exiting."
                EXIT 1
            }
        }
    }
}

Load-Module "Posh-ACME"
Import-Module "Posh-ACME"

$pArgs = @{
    AZSubscriptionId = 'ID GOES HERE'
    AZTenantId = 'ID GOES HERE'
    AZAppUsername = 'APPREG ID GOES HERE'
    AZCertThumbprint = 'CERTIFICATE THUMBPRINT GOES HERE'
}

# Construct the URL using string concatenation
$url = "https://dnskit.dk/_acme-challenge.$maindomain"

# Display the generated URL
Write-Host "Monitor the TXT record change here, and continue once it's set/changed:"
Write-Host "Generated URL: $url"

New-PACertificate $alldomain -AcceptTOS -PfxPass $pfxpass -Plugin Azure -PluginArgs $pArgs -Force

# Generate PFX certifikat 
$certname = "VB365-$(get-date -format yyyyMMdd)"
if (-not (Test-Path -Path "C:\Posh-ACME")) {
    mkdir "C:\Posh-ACME"
}

$pfxfile = "C:\Posh-ACME\$certname.pfx"
$cert = Get-PACertificate -MainDomain $maindomain
Copy-Item -Path $cert.PfxFile -Destination C:\Posh-ACME\$certname.pfx



#Import PFX certificate


$securepassword = $pfxpass | ConvertTo-SecureString -AsPlainText -Force

Set-VBORestAPISettings -CertificateFilePath "C:\Posh-ACME\$certname.pfx" -CertificatePassword $securepassword

Stop-Transcript