﻿# Run this first: powershell.exe -ExecutionPolicy Bypass -File "./InstallScript.ps1"
# Set the execution policy to RemoteSigned for the current process
#Run this Set-ExecutionPolicy RemoteSigned -Scope Process

Start-Transcript -Path c:\tmp\logs\InstallScript.txt -Append

# Make the folder if not already created
$folderPath = "C:\Scripts\VB365SSL"

if (-Not (Test-Path -Path $folderPath -PathType Container)) {
    New-Item -Path $folderPath -ItemType Directory
    Write-Host "Folder created at $folderPath"
} else {
    Write-Host "Folder already exists at $folderPath"
}

# Copy the scripts
$sourcePathRenewSSL = Join-Path -Path $PSScriptRoot -ChildPath "RenewSSL.ps1"
$sourcePathInitialSSL = Join-Path -Path $PSScriptRoot -ChildPath "InitialSSL.ps1"


################################################################
# Set the path for the certificate file
#$certificatePath = Join-Path -Path $PSScriptRoot -ChildPath "any.cloud.azure.cer"
# Define paths and password
#$pfxPath = "C:\Path\To\YourCertificate.pfx"

$pfxPath = Join-Path -Path $PSScriptRoot -ChildPath "CertAppRegAzure.pfx"
$pfxPassword = "e!..#h3110!H4U!!def"

# Load the certificate
$certificate = New-Object System.Security.Cryptography.X509Certificates.X509Certificate2
try {
    $certificate.Import($pfxPath, $pfxPassword, [System.Security.Cryptography.X509Certificates.X509KeyStorageFlags]::Exportable)
    Write-Host "Certificate successfully imported."
} catch {
    Write-Host "Failed to import the PFX file. Error: $_"
    exit 1
}

# Validate the certificate
if (-Not $certificate.Handle) {
    Write-Host "The certificate object is invalid. Check the PFX file and password."
    exit 1
}

# Add certificate to Local Machine's Personal store
$store = New-Object System.Security.Cryptography.X509Certificates.X509Store "My", "LocalMachine"
$store.Open("ReadWrite")
$store.Add($certificate)
$store.Close()
Write-Host "Certificate added to Local Machine's Personal store."

# Add certificate to Current User's Personal store (optional)
$store = New-Object System.Security.Cryptography.X509Certificates.X509Store "My", "CurrentUser"
$store.Open("ReadWrite")
$store.Add($certificate)
$store.Close()
Write-Host "Certificate added to Current User's Personal store."

########################################################################

Copy-Item -Path $sourcePathRenewSSL -Destination $folderPath
Copy-Item -Path $sourcePathInitialSSL -Destination $folderPath

Write-Host "Files copied to $folderPath"

# Get config entries
$maindomain = Read-Host "Enter the main domain (e.g., vb365controller.domain.com)"
$subdomain = Read-Host "Enter the subdomain (leave blank if none)"
$alldomain = Read-Host "Enter the all domain (e.g., vb365controller.domain.com)"
$pfxpass = Read-Host "Enter the PFX password"

$configFilePath = Join-Path $folderPath "ssl.config"

@"
maindomain=$maindomain
subdomain=$subdomain
alldomain=$alldomain
pfxpass=$pfxpass
"@ | Out-File -FilePath $configFilePath -Encoding utf8

Write-Host "ssl.config file created with the provided values."

# Run InitialSSL.ps1
$initialSSLPath = Join-Path $folderPath "InitialSSL.ps1"
powershell.exe -ExecutionPolicy Bypass -File $initialSSLPath

# Set the execution policy back to RemoteSigned for this process
Set-ExecutionPolicy RemoteSigned -Scope Process -Force

# Run SSLRenewTask.ps1
$scriptFullPath = Join-Path $PSScriptRoot "SSLRenewTask.ps1"
powershell.exe -ExecutionPolicy Bypass -File $scriptFullPath

Stop-Transcript
