﻿Start-Transcript -Path c:\tmp\logs\RenewSSLLog.txt -Append
Set-ExecutionPolicy RemoteSigned -Scope Process
# Step 1: Set the execution policy to Unrestricted for the current session
Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope Process -Force

# Define the path to the config file
$configFilePath = "C:\Scripts\VB365SSL\ssl.config"

# Read the content of the config file
$configContent = Get-Content $configFilePath

# Loop through each line in the config file and create variables
foreach ($line in $configContent) {
    # Skip empty lines or lines that don't have an '='
    if ($line -match "=") {
        # Split the line into key and value
        $key, $value = $line -split "=", 2
        # Trim any whitespace and create a variable dynamically
        Set-Variable -Name $key.Trim() -Value $value.Trim()
    }
}
$pArgs = @{
    AZSubscriptionId = 'ID GOES HERE'
    AZTenantId = 'ID GOES HERE'
    AZAppUsername = 'APPREG ID GOES HERE'
    AZCertThumbprint = 'CERTIFICATE THUMBPRINT GOES HERE'
}

$maxRetries = 5
$retryCount = 0
$success = $false

while (-not $success -and $retryCount -lt $maxRetries) {
    try {
        Submit-Renewal -MainDomain $maindomain -Force -PluginArgs $pArgs
        $success = $true
    } catch {
        $retryCount++
        Write-Host "Attempt $retryCount failed due to a nonce error. Retrying..."
        Start-Sleep -Seconds 10  # Wait for a moment before retrying
    }
}

if (-not $success) {
    Write-Error "Failed to renew certificate after $maxRetries attempts."
    Stop-Transcript
    exit 1
}

# Convert to pfx. 

$certname = "VB365-$(get-date -format yyyyMMdd)"
$pfxfile = "C:\Posh-ACME\$certname.pfx"
$cert = Get-PACertificate -MainDomain $maindomain
Copy-Item -Path $cert.PfxFile -Destination C:\Posh-ACME\$certname.pfx
# Import the certificate to Veeam Backup 365

$securepassword = $pfxpass | ConvertTo-SecureString -AsPlainText -Force

Set-VBORestAPISettings -CertificateFilePath "C:\Posh-ACME\$certname.pfx" -CertificatePassword $securepassword


Stop-Transcript
